/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.*;

/**
 * Bestimmt das Ergebnis des Gammaoperators zweier Zugehörigkeiten.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public final class GammaOperator implements Ausdruck<Zugehoerigkeit> {

    private final Ausdruck<Zugehoerigkeit> a;
    private final Ausdruck<Zugehoerigkeit> b;
    private final Ausdruck<Zugehoerigkeit> gamma;

    public GammaOperator(Ausdruck<Zugehoerigkeit> a, Ausdruck<Zugehoerigkeit> b, Ausdruck<Zugehoerigkeit> gamma) {
        this.a = Objects.requireNonNull(a, "a");
        this.b = Objects.requireNonNull(b, "b");
        this.gamma = Objects.requireNonNull(gamma, "gamma");
    }

    public Ausdruck<Zugehoerigkeit> getA() {
        return a;
    }

    public Ausdruck<Zugehoerigkeit> getB() {
        return b;
    }

    public Ausdruck<Zugehoerigkeit> getGamma() {
        return gamma;
    }

    @Override
    public Zugehoerigkeit interpretiere(Map<String, ?> kontext) {
        return Funktionen.gammaOperator(
                a.interpretiere(kontext),
                b.interpretiere(kontext),
                gamma.interpretiere(kontext)
        );
    }

    @Override
    public String toString() {
        return "gamma(" + a + ", " + b + ", " + gamma + ")";
    }

}
