/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.*;

/**
 * Bestimmt das Maximum von Zugehörigkeiten.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public final class Maximum implements Ausdruck<Zugehoerigkeit> {

    private final List<? extends Ausdruck<Zugehoerigkeit>> operanden;

    public Maximum(List<? extends Ausdruck<Zugehoerigkeit>> operanden) {
        Objects.requireNonNull(operanden, "operanden");
        this.operanden = Collections.unmodifiableList(new ArrayList<>(operanden));
    }

    public List<? extends Ausdruck<Zugehoerigkeit>> getOperanden() {
        return operanden;
    }

    @Override
    public Zugehoerigkeit interpretiere(Map<String, ?> kontext) {
        if (operanden.stream().anyMatch(Objects::isNull)) {
            return Zugehoerigkeit.NULL;
        }

        return operanden.stream()
                .map(o -> o.interpretiere(kontext))
                .reduce(Funktionen::maximum)
                .orElseThrow(() -> new IllegalStateException("Für die Bestimmung des Maximums wird mindestens ein Operand benötigt."));
    }

    @Override
    public String toString() {
        return "max(" +
                operanden.stream()
                        .map(Object::toString)
                        .reduce((o1, o2) -> o1 + ", " + o2)
                        .orElse("keine Operanden")
                + ")";
    }

}
