/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.*;
import java.util.function.*;

/**
 * Definiert eine Operation mit einem Operator.
 *
 * @param <T> das Ergebnis des Ausdrucks.
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public class Operation<T> implements Ausdruck<T> {

    private Function<T, T> operation;
    private final Ausdruck<T> a;

    public Operation(Function<T, T> operation, Ausdruck<T> a) {
        this.operation = Objects.requireNonNull(operation, "operation");
        this.a = Objects.requireNonNull(a, "a");
    }

    public Ausdruck<T> getA() {
        return a;
    }

    @Override
    public T interpretiere(Map<String, ?> kontext) {
        return operation.apply(a.interpretiere(kontext));
    }

}
