/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.*;

/**
 * Der Wertebereich einer Messgröße definiert durch sein Minimum und Maximum.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public final class Wertebereich {

    public static final Wertebereich KEINE_EINSCHRAENKUNG = new Wertebereich(Double.MIN_VALUE, Double.MAX_VALUE);

    private final double minimum;
    private final double maximum;

    public Wertebereich(double minimum, double maximum) {
        if (minimum >= maximum) {
            throw new IllegalArgumentException("Das Minimum muss kleiner sein, als das Maximum.");
        }

        this.minimum = minimum;
        this.maximum = maximum;
    }

    public double getMinimum() {
        return minimum;
    }

    public double getMaximum() {
        return maximum;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Wertebereich that = (Wertebereich) o;
        return Double.compare(that.minimum, minimum) == 0 &&
                Double.compare(that.maximum, maximum) == 0;
    }

    @Override
    public int hashCode() {
        return Objects.hash(minimum, maximum);
    }

    @Override
    public String toString() {
        if (this.equals(KEINE_EINSCHRAENKUNG)) {
            return "keine Einschränkung";
        } else {
            return minimum + "-" + maximum;
        }
    }

}
