/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.*;

/**
 * Ein Term beschreibt die Zugehörigkeit zu einem Fuzzy-Set.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @see FuzzySet
 */
public final class Term {

    private final String name;
    private final Zugehoerigkeit zugehoerigkeit;

    public Term(String name, Zugehoerigkeit zugehoerigkeit) {
        this.name = Objects.requireNonNull(name, "name");
        this.zugehoerigkeit = Objects.requireNonNull(zugehoerigkeit, "zugehoerigkeit");
    }

    public Term mitZugehoerigkeit(Zugehoerigkeit zugehoerigkeit) {
        return new Term(name, zugehoerigkeit);
    }

    public String getName() {
        return name;
    }

    public Zugehoerigkeit getZugehoerigkeit() {
        return zugehoerigkeit;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Term term = (Term) o;
        return Objects.equals(name, term.name) &&
                Objects.equals(zugehoerigkeit, term.zugehoerigkeit);
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, zugehoerigkeit);
    }

    @Override
    public String toString() {
        return name + ": " + zugehoerigkeit;
    }

}
