/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.*;

/**
 * Stellt eine Variable eines Terms in einem Ausdruck dar, das Ergebnis ist die
 * Zugehörigkeit des Terms.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public final class TermVariable implements Ausdruck<Zugehoerigkeit> {

    private final String fuzzyVariable;
    private final String term;

    public TermVariable(String fuzzyVariable, String term) {
        this.fuzzyVariable = Objects.requireNonNull(fuzzyVariable, "fuzzyVariable");
        this.term = Objects.requireNonNull(term, "term");
    }

    public String getFuzzyVariable() {
        return fuzzyVariable;
    }

    public String getTerm() {
        return term;
    }

    @Override
    public Zugehoerigkeit interpretiere(Map<String, ?> kontext) {
        Object variable = kontext.get(fuzzyVariable);
        if (variable == null) {
            throw new IllegalStateException("Die Variable \"" + fuzzyVariable + "\" ist nicht definiert.");
        }
        if (!(variable instanceof FuzzyVariable)) {
            throw new IllegalStateException("Die Variable \"" + fuzzyVariable + "\" muss eine Fuzzy-Variable sein.");
        }

        FuzzyVariable fuzzyVariable = (FuzzyVariable) variable;
        Term t = fuzzyVariable.gibTerm(term);
        return t.getZugehoerigkeit();
    }

    @Override
    public String toString() {
        return fuzzyVariable + "[" + term + "]";
    }

}
