/*
 * Segment 5 Intelligente Analyseverfahren, SW-Einheit 5.4 Funktionen Fuzzy
 * Copyright (C) 2007-2018 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.fuzzylib.fuzzylib;

import java.util.*;

/**
 * Die Zugehörigkeit ist eine Gleitkommazahl zwischen 0.0 und 1.0.
 * <p>
 * Die Zugehörigkeit kann undefiniert ({@link #isNull()}) sein.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public final class Zugehoerigkeit implements Comparable<Zugehoerigkeit> {

    public static final Zugehoerigkeit NULL = new Zugehoerigkeit(-1);

    private final int wert;

    private Zugehoerigkeit(double wert) {
        this.wert = (int) Math.round(wert * 1000.0);
    }

    public static Zugehoerigkeit von(double wert) {
        if (wert < 0 || wert > 1) {
            throw new IllegalArgumentException("Die Zugehörigkeit muss zwischen 0.0 und 1.0 liegen: " + wert);
        }
        return new Zugehoerigkeit(wert);
    }

    public static Zugehoerigkeit vonNullwert(Double wert) {
        if (wert == null) {
            return NULL;
        } else {
            return von(wert);
        }
    }

    public double getWert() {
        return wert / 1000.0;
    }

    public boolean isNull() {
        return wert < 0;
    }

    public boolean nonNull() {
        return !isNull();
    }

    @Override
    public int compareTo(Zugehoerigkeit z) {
        return Integer.compare(wert, z.wert);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Zugehoerigkeit that = (Zugehoerigkeit) o;
        return Objects.equals(wert, that.wert);
    }

    @Override
    public int hashCode() {
        return Objects.hash(wert);
    }

    @Override
    public String toString() {
        if (nonNull()) {
            return String.valueOf(getWert());
        } else {
            return "null";
        }
    }

}
